@@ -1,5 +1,5 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- * $Id: TestSuite.java,v 1.26 2001/01/22 15:58:20 metlov Exp $
+ * $Id: TestSuite.java,v 1.28 2001/02/20 16:01:42 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -24,7 +24,7 @@ public class TestSuite {
   
   static int successes=0;
   static int failures=0;
-  static boolean abort_at_error=true;// Set if You want to abort at a failing
+  static boolean abort_at_error=false;// Set if You want to abort at a failing
   // test, works only for testExpression().
   
   public static void main(String[] args) {
@@ -94,6 +94,15 @@ public class TestSuite {
     testExpression("2*2",new Integer(4),null,null,lib,o);
     testExpression("2L*2L",new Long(4),null,null,lib,o);
     testExpression("2.0*2.0",new Double(4.0),null,null,lib,o);
+
+    testExpression("2*2+3*3",new Integer(13),null,null,lib,o);
+    testExpression("2/2+3/3",new Integer(2),null,null,lib,o);
+    testExpression("2%2+3%3",new Integer(0),null,null,lib,o);
+
+    testExpression("2*2-3*3",new Integer(-5),null,null,lib,o);
+    testExpression("2/2-3/3",new Integer(0),null,null,lib,o);
+    testExpression("2%2-3%3",new Integer(0),null,null,lib,o);
+
     testExpression("2.0F*2.0F",new Float(4.0F),null,null,lib,o);
     testExpression("sin(1)",new Double(Math.sin(1.0)),null,null,lib,o);
     testExpression("pow(sin(1),2)+pow(cos(1),2)",new Double(1.0),null,null,
@@ -248,7 +257,15 @@ public class TestSuite {
     testExpression("(int)4.0",
                    new Integer(4),null,null,lib,o);
 
-    
+    testExpression("-(int)234",
+                   new Integer(-234),null,null,lib,o);
+
+    testExpression("-(short)(-(int)234)",
+                   new Integer(234),null,null,lib,o);
+
+    testExpression("!(boolean)(true)",
+                   Boolean.FALSE,null,null,lib,o);
+
     testExpression("7+(int)4-(int)6.0+1-(int)round((double)((float)((long)1+0)+0)+0)",
                    new Integer(5),null,null,lib,o);
     
@@ -261,8 +278,6 @@ public class TestSuite {
 
     testExpression("\"abbb\".substring(1).equals(\"bbb\")||false",
                    Boolean.TRUE,null,null,lib,o);
-    //    testExpression("equals(substring(\"abbb\",1),\"bbb\")||false",
-    //    Boolean.TRUE,null,null,lib,o);
 
     o.println(); 
     o.println("----- TESTING VIRTUAL METHODS (x=5.0D) ------");
@@ -291,6 +306,21 @@ public class TestSuite {
     testExpression("7+(int)4-(int)6.0+(int)x-(int)round((double)((float)((long)x+1)+2)+3)+6",
                    new Integer(5),null,rtp,lib,o);
 
+    testExpression("x",new Double(5.0),null,rtp,lib,o);
+    testExpression("(x)",new Double(5.0),null,rtp,lib,o);
+    testExpression("(-x)",new Double(-5.0),null,rtp,lib,o);
+    testExpression("(x())",new Double(5.0),null,rtp,lib,o);
+
+    testExpression("xS<4.0",Boolean.FALSE,null,rtp,lib,o);
+    testExpression("xXS<4.0",Boolean.FALSE,null,rtp,lib,o);
+    testExpression("x<4.0",Boolean.FALSE,null,rtp,lib,o);
+    testExpression("xX<4.0",Boolean.FALSE,null,rtp,lib,o);
+
+    testExpression("xS<4.0",Boolean.FALSE,Boolean.TYPE,rtp,lib,o);
+    testExpression("xXS<4.0",Boolean.FALSE,Boolean.TYPE,rtp,lib,o);
+    testExpression("x<4.0",Boolean.FALSE,Boolean.TYPE,rtp,lib,o);
+    testExpression("xX<4.0",Boolean.FALSE,Boolean.TYPE,rtp,lib,o);
+    
     o.println(); o.println("----- VARIABLE AND ARRAY ACCESS ------");
     o.println();
     testExpression("5*xvar-66",new Double(25-66),Double.TYPE,rtp,lib,o);
@@ -309,12 +339,13 @@ public class TestSuite {
 
     o.println(); o.println("----- DOT OPERATOR ------");
     // Construct a new library
-    Class[] dotLib=new Class[4];
+    Class[] dotLib=new Class[5];
     try {
       dotLib[0]=Class.forName("java.lang.String");
       dotLib[1]=Class.forName("java.lang.Double");
       dotLib[2]=Class.forName("gnu.jel.reflect.Double");
-      dotLib[3]=DoubleObject.class;
+      dotLib[3]=IntegerObject.class;
+      dotLib[4]=DoubleObject.class;
     } catch(ClassNotFoundException e) {
       System.out.println(e);
       System.exit(1);
@@ -325,6 +356,7 @@ public class TestSuite {
     testExpression("(\"abc\").length()", new Integer(3), null, rtp, lib,o);
     testExpression("\"abc\".length()", new Integer(3), null, rtp, lib,o);
     testExpression("\"abc\".endsWith(\"bc\")", Boolean.TRUE, null, rtp, lib,o);
+    testExpression("\"abc\".compareTo(\"bc\")", new Integer(-1), null, rtp, lib,o);
     testExpression("\"abcdbc\".indexOf(\"bc\")", new Integer(1), null, rtp, lib,o);
     testExpression("\"abcdbc\".indexOf(\"abc\".substring(1),2)", new Integer(4), null, rtp, lib,o);
 
@@ -363,6 +395,15 @@ public class TestSuite {
     testExpression("p1.s2.length()", new Integer(9), null, rtp, lib,o);
     testExpression("p1+(p1.d1+p1.s2.length()+1)", "p1value11.0", null, rtp, lib,o);
     testExpression("round(p1.d1)", new Long(1), null, rtp, lib,o);
+    testExpression("round(makeDoubleObject(p1.d1))", new Long(1), null,
+                   rtp, lib,o);
+    testExpression("\"abc\".compareTo(\"\"+makeDoubleObject(p1.d1))>0",
+                   Boolean.TRUE, Boolean.TYPE,rtp, lib,o);
+    testExpression("\"abc\".compareTo((2>round(makeDoubleObject(p1.d1))?"+
+                   "\"\":\"a\")+"+
+                   "makeDoubleObject(p1.d1))>0",
+                   Boolean.TRUE, null,rtp, lib,o);
+
     testExpression("p1.d1>0", new Boolean(true), null, rtp, lib,o);
     testExpression("p1.d1>0?p1.d1:3.0", new Double(1.0), null, rtp, lib,o);
     testExpression("p1.b1t", new Boolean(true), Boolean.TYPE, rtp, lib,o);
@@ -386,6 +427,10 @@ public class TestSuite {
     testExpression("\"a\"+\"b\"+aarr[1][0]+\"c\"","ab3.0c", null, rtp, lib,o);
 
 
+//      o.println(); o.println("----- MULTI-ROOT DYNAMIC VARIABLES ------");
+//      vp.addProperty("<IntegerObject>p1","irrelevant value");
+//      testExpression("makeJELIntegerObject(2).p1", "p1", null, rtp, lib,o);
+
     // Test case for a bug submitted by Dave Ekhaus
     {
       for(int i=0;i<8;i++) {
@@ -472,7 +517,6 @@ public class TestSuite {
     testExpression("methodOnInt(valIntegerJELObj)",new Integer(2), 
                    null, rtp, lib, o);
 
-
     for(int k=0;k<2;k++) {
       o.println(); 
       o.println("----- THOROUGNLY TEST UNARY OPERATIONS  ------");
