@@ -1,5 +1,5 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- * $Id: Evaluator.java,v 1.10 2000/09/09 19:51:48 metlov Exp $
+ * $Id: Evaluator.java,v 1.11 2000/11/12 14:59:34 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -82,7 +82,7 @@ public class Evaluator {
         new LocalMethod(0x0001,Void.TYPE,"<init>",null,null);
       cf.newMethod(cnstr,null);
       cf.code(0x2a);                //| aload_0  ;loads "this"
-      cf.typesStk.push(null);
+      cf.typesStk.pushID(11); // not important what, it must be a reference
       Method supInit=new Method(cmplExpr.getConstructor(new Class[0]));
       cf.code(0xb7);                //| invokespecial
       cf.codeI(cf.getIndex(supInit,10));  //|    super();
