@@ -1,5 +1,5 @@
 /*-*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- * $Id: Library.java,v 1.10 2001/01/22 15:58:20 metlov Exp $
+ * $Id: Library.java,v 1.11 2001/02/20 16:01:41 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -58,8 +58,9 @@ public class Library {
 
   private Hashtable dotClasses; // Hashtable(classes, Hashtable(names, Hashtable(signatures, members)))
   private boolean noDotSecurity=false;
-  
-  private DVResolver resolver;
+
+  public DVResolver resolver;   // directly accessed from EC.jj
+
   private Class provider=null;
 
   /**
@@ -247,10 +248,15 @@ public class Library {
     return stateless.containsKey(o);
   };
 
-  public String getDVTypeName(String name) {
-    if (resolver==null) return null;
-    return resolver.getTypeName(name);
-  };
+//  gives nothing the direct acces to resolver is not able to give
+//  plus reduces flexibility (to change resilver at run-time)
+//  also the direct acces allows more optimizations
+//  and also removing this method saves space.
+//
+//    public String getDVTypeName(String name) {
+//      if (resolver==null) return null;
+//      return resolver.getTypeName(name);
+//    };
   
   /**
    * Used to search library for method or field.
