@@ -1,5 +1,5 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- 
- * $Id: OPlist.java,v 1.2 2000/09/09 19:51:48 metlov Exp $
+ * $Id: OPlist.java,v 1.3 2001/02/20 16:01:42 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -64,10 +64,9 @@ public class OPlist extends OP {
   };
 
   public void addAfter(OP e, OP ne) {
-    if (e.next!=null)
-      addBefore(e.next,ne);
-    else
-      addLast(ne);
+    if (e==null) addFirst(ne);
+    else if (e.next!=null) addBefore(e.next,ne);
+    else addLast(ne);
   };
   
   public void remove(OP o) {
