@@ -1,5 +1,5 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- 
- * $Id: TableKeeper.java,v 1.4 2001/01/22 15:58:20 metlov Exp $
+ * $Id: TableKeeper.java,v 1.5 2001/02/15 00:07:50 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -165,10 +165,10 @@ public class TableKeeper {
         //L 0000 0000 0000
         //V 0000 0000 0000
         //T 0000 0000 0001
-        //S 0000 0000 1011
+        //S 0000 0000 0011
         int[] cvt_wide= {
           0x800,0x400,0x600,0x500,0x780,0x7C0,0x5E0,0x5F0,0x000,
-          0x000,0x001,0x00B
+          0x000,0x001,0x003
         };
         tables.put("cvt_wide",cvt_wide);
 
