@@ -1,5 +1,5 @@
 /*-*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- * $Id: VariableProvider.java,v 1.11 2001/01/22 15:58:20 metlov Exp $
+ * $Id: VariableProvider.java,v 1.13 2001/02/20 16:01:42 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -18,6 +18,9 @@ public class VariableProvider implements gnu.jel.DVResolver {
   public double xvar;
   
   public double x() {return xvar;};
+  public static double xS() {return 5.3;};
+  public java.lang.Double xX() {return new java.lang.Double(xvar);};
+  public static java.lang.Double xXS() {return new java.lang.Double(5.3);};
 
   // --- Dynamic variables testing section
 
@@ -178,7 +181,7 @@ public class VariableProvider implements gnu.jel.DVResolver {
     return new ShortObject(v);
   };
 
-  public static gnu.jel.reflect.Integer makeJELIntegerObject(int v) {
+  public static IntegerObject makeJELIntegerObject(int v) {
     return new IntegerObject(v);
   };
 
